@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-26 15:26:32
-@LastEditTime: 2021-12-09 09:58:40
+@LastEditTime: 2022-02-16 19:13:25
 @LastEditors: HuangJianYi
 :Description: 活动处理
 """
@@ -30,17 +30,17 @@ class MachineListHandler(SevenBaseHandler):
         :param act_id:活动id
         :param page_index:页索引
         :param page_size:页大小
-        :param price_gear_id:价格挡位id
+        :param price_gear_id:价格档位id
+        :param integral_gear_id:会员积分档位id
         :param series_id:卖家ID
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
         act_id = int(self.get_param("act_id", 0))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         price_gear_id = int(self.get_param("price_gear_id", 0))
+        integral_gear_id = int(self.get_param("integral_gear_id", 0))
         series_id = int(self.get_param("series_id", 0))
         now_date = self.get_now_datetime()
 
@@ -53,6 +53,9 @@ class MachineListHandler(SevenBaseHandler):
         if price_gear_id > 0:
             condition += " AND price_gears_id=%s"
             params.append(price_gear_id)
+        if integral_gear_id > 0:
+            condition += " AND machine_price=%s"
+            params.append(str(price_gear_id)+".00")
         if series_id > 0:
             condition += " AND series_id=%s"
             params.append(series_id)
@@ -364,4 +367,26 @@ class MinboxListHandler(SevenBaseHandler):
 
         self.redis_init().set(f"minbox_list_{str(open_id)}_{str(key_id)}", self.json_dumps(redis_prize_dict), ex=3600 * 1)
 
-        return self.reponse_json_success(result_info)
\ No newline at end of file
+        return self.reponse_json_success(result_info)
+
+
+class CrmIntegralGearlListHandler(SevenBaseHandler):
+    """
+    :description: 会员积分档位列表
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description:  会员积分档位列表
+        :return: 分页列表信息
+        :last_editors: HuangJingCan
+        """
+        act_id = int(self.get_param("act_id", 0))
+        condition = "is_release=1 AND act_id=%s AND machine_type=3"
+        params = [act_id]
+        integra_gear_list = []
+        machine_info_list_dict = MachineInfoModel(context=self).get_dict_list(condition, order_by="sort_index desc", field="machine_price", params=params)
+        for machine_info_dict in machine_info_list_dict:
+            if int(machine_info_dict["machine_price"]) not in integra_gear_list:
+                integra_gear_list.append(int(machine_info_dict["machine_price"]))
+        return self.reponse_json_success(integra_gear_list)
\ No newline at end of file
