@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2021-04-14 15:02:54
-@LastEditTime: 2021-09-01 14:40:00
+@LastEditTime: 2022-02-17 18:36:09
 @LastEditors: HuangJianYi
 :Description: 用户权限相关
 """
@@ -41,5 +41,6 @@ class ShopPowerConfigHandler(SevenBaseHandler):
         app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
         if not app_info:
             return self.reponse_json_error("NoApp", "对不起，找不到该小程序")
-        power_base_model = PowerBaseModel()
-        self.reponse_json_success(power_base_model.get_config_data(app_info.store_user_nick, self.get_taobao_param().access_token))
+        power_base_model = PowerBaseModel(context=self)
+        app_key, app_secret = self.get_app_key_secret()
+        self.reponse_json_success(power_base_model.get_config_data(app_info.store_user_nick, app_info.access_token, app_key, app_secret))
