@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-09-14 17:09:17
+@LastEditTime: 2022-02-17 18:29:10
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -34,6 +34,29 @@ from seven_cloudapp_ppmt.models.db_models.act.act_info_model import *
 from seven_cloudapp_ppmt.models.db_models.prop.prop_give_model import *
 
 
+class GetCrmIntegralHandler(TopBaseHandler):
+    """
+    :description: 获取店铺会员积分
+    """
+    @filter_check_params()
+    def get_async(self):
+        """
+        :description: 获取店铺会员积分
+        :return: 店铺会员积分
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_taobao_param().source_app_id
+        user_nick = self.get_taobao_param().user_nick
+        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
+        if app_info:
+            access_token = app_info.access_token
+        invoke_result_data = self.get_crm_point_available(user_nick, access_token)
+        if invoke_result_data.success == False:
+            return self.reponse_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        shop_member_integral = invoke_result_data.data
+        return self.reponse_json_success(shop_member_integral)
+
+
 class SyncPayOrderHandler(TopBaseHandler):
     """
     :description: 用户支付订单提交
@@ -64,7 +87,7 @@ class SyncPayOrderHandler(TopBaseHandler):
             return self.reponse_json_error('NoAct', '对不起，活动不存在')
 
         #请求太频繁限制
-        if self.check_post(f"SyncPayOrderHandler_Post_{str(act_id)}_{str(open_id)}", expire=10) == False:
+        if self.check_post(f"SyncPayOrderHandler_Post_{str(act_id)}_{str(open_id)}", expire=3) == False:
             return self.reponse_json_error("NoUser", "对不起，请稍后再试")
 
         # 获取订单
