@@ -2,12 +2,12 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-@LastEditTime: 2021-10-08 14:48:16
+@LastEditTime: 2022-02-16 19:02:35
 @LastEditors: HuangJianYi
 :description: 订单相关
 """
 from seven_cloudapp.handlers.seven_base import *
-
+from seven_cloudapp.libs.customize.oss2help import *
 from seven_cloudapp.models.seven_model import PageInfo
 from seven_cloudapp.models.db_models.pay.pay_order_model import *
 from seven_cloudapp.models.db_models.prize.prize_order_model import *
@@ -223,9 +223,11 @@ class PrizeOrderExportHandler(SevenBaseHandler):
         """
         :description: 批量导出
         :param main_pay_order_no:淘宝主订单编号
+        :param export_type:导出类型0文本1文件
         :return 
         :last_editors: CaiYouBin
         """
+        export_type = int(self.get_param("export_type", 0))
         main_pay_order_no = self.get_param("main_pay_order_no")
         pay_order_no = self.get_param("pay_order_no")
         act_id = int(self.get_param("act_id", 0))
@@ -286,54 +288,118 @@ class PrizeOrderExportHandler(SevenBaseHandler):
         prize_order_model = PrizeOrderModel(context=self)
         prize_roster_model = PrizeRosterModel(context=self)
 
-        #奖品订单
-        prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, condition, order_by="create_date desc", params=params)
+        if export_type == 1:
+            #奖品订单
+            prize_order_list_dict, total = PrizeOrderModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", "create_date desc", params)
 
-        data_columns = ["淘宝主订单号", "淘宝子订单号", "小程序订单号", "淘宝名", "盒子名称", "盒子价格", "奖品名称", "商家编码", "姓名", "手机号", "省份", "城市", "区县", "街道", "收货地址", "物流单号", "物流公司", "发货时间", "订单状态", "奖品价值", "奖品规格", "备注"]
+            result_data = []
+            if len(prize_order_list_dict) > 0:
+                prize_order_id_list = [prize_order["id"] for prize_order in prize_order_list_dict]
+                prize_order_ids = str(prize_order_id_list).strip('[').strip(']')
+                #订单奖品
+                prize_roster_list = PrizeRosterModel(context=self).get_dict_list("prize_order_id in (" + prize_order_ids + ")", order_by="id desc")
 
-        data_text = ",".join(list(map(lambda x: "\"" + x + "\"", data_columns))) + "\n"
+                for prize_order in prize_order_list_dict:
+                    prize_roster_list_filter = [prize_roster for prize_roster in prize_roster_list if prize_roster["prize_order_id"] == prize_order["id"]]
+                    for prize_roster in prize_roster_list_filter:
+                        data_row = {}
+                        data_row["淘宝主订单号"] = prize_order["order_no"]
+                        data_row["淘宝子订单号"] = prize_roster["order_no"]
+                        data_row["小程序订单号"] = prize_order["order_no"]
+                        data_row["淘宝名"] = prize_order["user_nick"]
+                        data_row["盒子名称"] = prize_roster["machine_name"]
+                        data_row["盒子价格"] = str(prize_roster["machine_price"])
+                        data_row["奖品名称"] = prize_roster["prize_name"]
+                        data_row["商家编码"] = prize_roster["goods_code"]
+                        data_row["姓名"] = prize_order["real_name"]
+                        data_row["手机号"] = prize_order["telephone"]
+                        data_row["省份"] = prize_order["province"]
+                        data_row["城市"] = prize_order["city"]
+                        data_row["区县"] = prize_order["county"]
+                        data_row["街道"] = prize_order["street"]
+                        data_row["收货地址"] = prize_order["adress"]
+                        data_row["物流单号"] = prize_order["express_no"]
+                        data_row["物流公司"] = prize_order["express_company"]
+                        if str(prize_order["deliver_date"]) == "1900-01-01 00:00:00":
+                            data_row["发货时间"] = ""
+                        else:
+                            data_row["发货时间"] = str(prize_order["deliver_date"])
+                        if str(prize_order["create_date"]) == "1900-01-01 00:00:00":
+                            data_row["下单时间"] = ""
+                        else:
+                            data_row["下单时间"] = str(prize_order["deliver_date"])
+                        data_row["订单状态"] = self.get_status_name(prize_order["order_status"])
+                        data_row["奖品价值"] = str(prize_roster["prize_price"])
+                        data_row["奖品规格"] = prize_roster["properties_name"]
+                        data_row["备注"] = prize_order["remarks"]
 
-        result_data = []
-        if len(prize_order_list_dict) > 0:
-            prize_order_id_list = [prize_order["id"] for prize_order in prize_order_list_dict]
-            prize_order_ids = str(prize_order_id_list).strip('[').strip(']')
-            #订单奖品
-            prize_roster_list = prize_roster_model.get_dict_list("prize_order_id in (" + prize_order_ids + ")", order_by="id desc")
+                        result_data.append(data_row)
 
-            for prize_order in prize_order_list_dict:
-                prize_roster_list_filter = [prize_roster for prize_roster in prize_roster_list if prize_roster["prize_order_id"] == prize_order["id"]]
-                for prize_roster in prize_roster_list_filter:
+            resource_path = ""
+            if result_data:
+                # if not os.path.exists("temp"):
+                #     os.makedirs("temp")
+                path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
+                ExcelHelper.export(result_data, path)
 
-                    data_row = []
-                    data_row.append("\'" + prize_roster["main_pay_order_no"])
-                    data_row.append("\'" + prize_roster["order_no"])
-                    data_row.append("\'" + prize_order["order_no"])
-                    data_row.append(prize_order["user_nick"])
-                    data_row.append(prize_roster["machine_name"])
-                    data_row.append(str(prize_roster["machine_price"]))
-                    data_row.append(prize_roster["prize_name"])
-                    data_row.append(prize_roster["goods_code"])
-                    data_row.append(prize_order["real_name"])
-                    data_row.append(prize_order["telephone"])
-                    data_row.append(prize_order["province"])
-                    data_row.append(prize_order["city"])
-                    data_row.append(prize_order["county"])
-                    data_row.append(prize_order["street"])
-                    data_row.append(prize_order["adress"])
-                    data_row.append(prize_order["express_no"])
-                    data_row.append(prize_order["express_company"])
-                    if str(prize_order["deliver_date"]) == "1900-01-01 00:00:00":
-                        data_row.append("")
-                    else:
-                        data_row.append(str(prize_order["deliver_date"]))
-                    data_row.append(self.get_status_name(prize_order["order_status"]))
-                    data_row.append(str(prize_roster["prize_price"]))
-                    data_row.append(prize_roster["properties_name"])
-                    data_row.append(prize_order["remarks"])
+                resource_path = OSS2Helper().upload("", path, "test", False)
 
-                    data_text = data_text + ",".join(list(map(lambda x: "\"" + x + "\"", data_row))) + "\n"
+                os.remove(path)
+            return self.reponse_json_success(resource_path)
+        else:
 
-        return self.reponse_json_success(data_text)
+            #奖品订单
+            prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, condition, order_by="create_date desc", params=params)
+
+            data_columns = ["淘宝主订单号", "淘宝子订单号", "小程序订单号", "淘宝名", "盒子名称", "盒子价格", "奖品名称", "商家编码", "姓名", "手机号", "省份", "城市", "区县", "街道", "收货地址", "物流单号", "物流公司", "发货时间","下单时间", "订单状态", "奖品价值", "奖品规格", "备注"]
+
+            data_text = ",".join(list(map(lambda x: "\"" + x + "\"", data_columns))) + "\n"
+
+            result_data = []
+            if len(prize_order_list_dict) > 0:
+                prize_order_id_list = [prize_order["id"] for prize_order in prize_order_list_dict]
+                prize_order_ids = str(prize_order_id_list).strip('[').strip(']')
+                #订单奖品
+                prize_roster_list = prize_roster_model.get_dict_list("prize_order_id in (" + prize_order_ids + ")", order_by="id desc")
+
+                for prize_order in prize_order_list_dict:
+                    prize_roster_list_filter = [prize_roster for prize_roster in prize_roster_list if prize_roster["prize_order_id"] == prize_order["id"]]
+                    for prize_roster in prize_roster_list_filter:
+
+                        data_row = []
+                        data_row.append("\'" + prize_roster["main_pay_order_no"])
+                        data_row.append("\'" + prize_roster["order_no"])
+                        data_row.append("\'" + prize_order["order_no"])
+                        data_row.append(prize_order["user_nick"])
+                        data_row.append(prize_roster["machine_name"])
+                        data_row.append(str(prize_roster["machine_price"]))
+                        data_row.append(prize_roster["prize_name"])
+                        data_row.append(prize_roster["goods_code"])
+                        data_row.append(prize_order["real_name"])
+                        data_row.append(prize_order["telephone"])
+                        data_row.append(prize_order["province"])
+                        data_row.append(prize_order["city"])
+                        data_row.append(prize_order["county"])
+                        data_row.append(prize_order["street"])
+                        data_row.append(prize_order["adress"])
+                        data_row.append(prize_order["express_no"])
+                        data_row.append(prize_order["express_company"])
+                        if str(prize_order["deliver_date"]) == "1900-01-01 00:00:00":
+                            data_row.append("")
+                        else:
+                            data_row.append(str(prize_order["deliver_date"]))
+                        if str(prize_order["create_date"]) == "1900-01-01 00:00:00":
+                            data_row.append("")
+                        else:
+                            data_row.append(str(prize_order["create_date"]))
+                        data_row.append(self.get_status_name(prize_order["order_status"]))
+                        data_row.append(str(prize_roster["prize_price"]))
+                        data_row.append(prize_roster["properties_name"])
+                        data_row.append(prize_order["remarks"])
+
+                        data_text = data_text + ",".join(list(map(lambda x: "\"" + x + "\"", data_row))) + "\n"
+
+            return self.reponse_json_success(data_text)
 
 
 class PrizeRosterListExportHandler(SevenBaseHandler):
@@ -344,9 +410,11 @@ class PrizeRosterListExportHandler(SevenBaseHandler):
         """
         :description: 批量奖品列表导出
         :param act_id:活动id
+        :param export_type:导出类型0文本1文件
         :return {*}
         :last_editors: CaiYouBin
         """
+        export_type = int(self.get_param("export_type", 0))
         act_id = int(self.get_param("act_id", 0))
         order_no = self.get_param("order_no")
         order_status = int(self.get_param("order_status", -1))
@@ -367,40 +435,70 @@ class PrizeRosterListExportHandler(SevenBaseHandler):
             params.append(order_status)
             condition += " AND order_status=%s"
 
-        prize_order_model = PrizeOrderModel(context=self)
         prize_roster_model = PrizeRosterModel(context=self)
 
-        #奖品订单
-        prize_roster_list, total = prize_roster_model.get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
-
-        data_columns = ["行为编号", "淘宝子订单号", "淘宝名", "盒子名称", "盒子价格", "奖品名称", "奖品价值", "SKU", "获得时间", "状态"]
-
-        data_text = ",".join(list(map(lambda x: "\"" + x + "\"", data_columns))) + "\n"
-
-        result_data = []
-        if len(prize_roster_list) > 0:
+        if export_type == 1:
+            
+            #奖品订单
+            prize_roster_list, total = PrizeRosterModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
             #订单奖品
+            result_data = []
             for prize_roster in prize_roster_list:
-                data_row = []
-                data_row.append(str(prize_roster["id"]))
-                if prize_roster["order_no"] == "":
-                    data_row.append(prize_roster["order_no"])
-                else:
-                    data_row.append("\'" + prize_roster["order_no"])
-                data_row.append(prize_roster["user_nick"])
-                data_row.append(prize_roster["machine_name"])
-                data_row.append(str(prize_roster["machine_price"]))
-                data_row.append(prize_roster["prize_name"])
-                data_row.append(str(prize_roster["prize_price"]))
-                data_row.append(prize_roster["properties_name"])
-                data_row.append(TimeHelper.datetime_to_format_time(prize_roster["create_date"]))
+                data_row = {}
+                data_row["行为编号"] = prize_roster["id"]
+                data_row["淘宝子订单号"] = prize_roster["order_no"]
+                data_row["淘宝名"] = prize_roster["user_nick"]
+                data_row["盒子名称"] = prize_roster["machine_name"]
+                data_row["盒子价格"] = str(prize_roster["machine_price"])
+                data_row["奖品名称"] = prize_roster["prize_name"]
+                data_row["奖品价值"] = str(prize_roster["prize_price"])
+                data_row["SKU"] = prize_roster["properties_name"]
+                data_row["获得时间"] = prize_roster["create_date"]
                 if prize_roster["prize_order_id"] == 0:
-                    data_row.append("未下单")
+                    data_row["状态"] = "未下单"
                 else:
-                    data_row.append("已下单")
-                data_text = data_text + ",".join(list(map(lambda x: "\"" + x + "\"", data_row))) + "\n"
+                    data_row["状态"] = "已下单"
+                result_data.append(data_row)
+            resource_path = ""
+            if result_data:
+                path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
+                ExcelHelper.export(result_data, path)
+                resource_path = OSS2Helper().upload("", path, config.get_value("oss_folder"), False)
+                os.remove(path)
 
-        return self.reponse_json_success(data_text)
+            return self.reponse_json_success(resource_path)
+
+        else:
+            #奖品订单
+            prize_roster_list, total = prize_roster_model.get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
+
+            data_columns = ["行为编号", "淘宝子订单号", "淘宝名", "盒子名称", "盒子价格", "奖品名称", "奖品价值", "SKU", "获得时间", "状态"]
+
+            data_text = ",".join(list(map(lambda x: "\"" + x + "\"", data_columns))) + "\n"
+
+            if len(prize_roster_list) > 0:
+                #订单奖品
+                for prize_roster in prize_roster_list:
+                    data_row = []
+                    data_row.append(str(prize_roster["id"]))
+                    if prize_roster["order_no"] == "":
+                        data_row.append(prize_roster["order_no"])
+                    else:
+                        data_row.append("\'" + prize_roster["order_no"])
+                    data_row.append(prize_roster["user_nick"])
+                    data_row.append(prize_roster["machine_name"])
+                    data_row.append(str(prize_roster["machine_price"]))
+                    data_row.append(prize_roster["prize_name"])
+                    data_row.append(str(prize_roster["prize_price"]))
+                    data_row.append(prize_roster["properties_name"])
+                    data_row.append(TimeHelper.datetime_to_format_time(prize_roster["create_date"]))
+                    if prize_roster["prize_order_id"] == 0:
+                        data_row.append("未下单")
+                    else:
+                        data_row.append("已下单")
+                    data_text = data_text + ",".join(list(map(lambda x: "\"" + x + "\"", data_row))) + "\n"
+
+            return self.reponse_json_success(data_text)
 
 
 class PrizeOrderImportHandler(SevenBaseHandler):
@@ -412,53 +510,93 @@ class PrizeOrderImportHandler(SevenBaseHandler):
         """
         :description: 批量导入(批量发货)
         :param content:内容
+        :param content_type:内容类型：0文本1base64字符串
         :param act_id:活动id
         :return: 
         :last_editors: CaiYouBin
         """
+        content_type = int(self.get_param("content_type", 0))
         content = self.get_param("content")
         act_id = self.get_param("act_id")
-        content_json = self.json_loads(content)
 
         prize_order_model = PrizeOrderModel(context=self)
         prize_roster_model = PrizeRosterModel(context=self)
 
-        order_no_index = -1
-        express_no_index = -1
-        express_company_index = -1
-        title_arr = content_json[0].replace("\'", "").split(",")
-        if len(title_arr) == 0:
-            return self.reponse_json_error("NoTitle", "对不起,未找到字段名称")
+        if content_type == 0:
+            content_json = self.json_loads(content)
+            order_no_index = -1
+            express_no_index = -1
+            express_company_index = -1
+            title_arr = content_json[0].replace("\'", "").split(",")
+            if len(title_arr) == 0:
+                return self.reponse_json_error("NoTitle", "对不起,未找到字段名称")
+            title_arr_index = 0
+            for title in title_arr:
+                title = title.replace("\"", "").replace("\'", "")
 
-        title_arr_index = 0
-        for title in title_arr:
-            title = title.replace("\"", "").replace("\'", "")
+                if "小程序订单号" == title:
+                    order_no_index = title_arr_index
+                if "物流公司" == title:
+                    express_company_index = title_arr_index
+                if "物流单号" == title:
+                    express_no_index = title_arr_index
+                title_arr_index += 1
 
-            if "小程序订单号" == title:
-                order_no_index = title_arr_index
-            if "物流公司" == title:
-                express_company_index = title_arr_index
-            if "物流单号" == title:
-                express_no_index = title_arr_index
-            title_arr_index += 1
+            if order_no_index == -1 or express_no_index == -1 or express_company_index == -1:
+                return self.reponse_json_error("NoTitle", "对不起,缺少必要字段，无法导入订单")
 
-        if order_no_index == -1 or express_no_index == -1 or express_company_index == -1:
-            return self.reponse_json_error("NoTitle", "对不起,缺少必要字段，无法导入订单")
+            for i in range(1, len(content_json)):
+                fields = content_json[i].replace("\'", "").split(",")
+                if len(fields) == 0:
+                    continue
+                #去掉多余的单（双）引号
+                order_no = fields[order_no_index].replace("\"", "").replace("\'", "")
+                express_no = fields[express_no_index].replace("\"", "").replace("\'", "")
+                express_company = fields[express_company_index].replace("\"", "").replace("\'", "")
+                if order_no and express_no and express_company:
+                    update_sql = "order_status=1,express_no=%s,express_company=%s,deliver_date=%s,modify_date=%s"
+                    params = [express_no, express_company, self.get_now_datetime(), self.get_now_datetime(), order_no, act_id]
+                    prize_order_model.update_table(update_sql, "order_no=%s and act_id=%s", params=params)
+                    prize_roster_model.update_table("order_status=1", "order_no=%s and act_id=%s", [order_no, act_id])
+        else:
+            data = base64.decodebytes(content.encode())
+            path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
+            with open(path, 'ba') as f:
+                buf = bytearray(data)
+                f.write(buf)
+            f.close()
 
-        for i in range(1, len(content_json)):
-            fields = content_json[i].replace("\'", "").split(",")
-            if len(fields) == 0:
-                continue
+            order_no_index = -1
+            express_no_index = -1
+            express_company_index = -1
 
-            #去掉多余的单（双）引号
-            order_no = fields[order_no_index].replace("\"", "").replace("\'", "")
-            express_no = fields[express_no_index].replace("\"", "").replace("\'", "")
-            express_company = fields[express_company_index].replace("\"", "").replace("\'", "")
+            data = ExcelHelper.input(path)
+            data_total = len(data)
+            # 表格头部
+            if data_total > 0:
+                title_list = data[0]
+                if "小程序订单号" in title_list:
+                    order_no_index = title_list.index("小程序订单号")
+                if "物流单号" in title_list:
+                    express_no_index = title_list.index("物流单号")
+                if "物流公司" in title_list:
+                    express_company_index = title_list.index("物流公司")
 
-            if order_no and express_no and express_company:
-                update_sql = "order_status=1,express_no=%s,express_company=%s,deliver_date=%s,modify_date=%s"
-                params = [express_no, express_company, self.get_now_datetime(), self.get_now_datetime(), order_no, act_id]
-                prize_order_model.update_table(update_sql, "order_no=%s and act_id=%s", params=params)
-                prize_roster_model.update_table("order_status=1", "order_no=%s and act_id=%s", [order_no, act_id])
+            if order_no_index == -1 or express_no_index == -1 or express_company_index == -1:
+                return self.reponse_json_error("NoTitle", "对不起,缺少必要字段，无法导入订单")
 
-        return self.reponse_json_success()
\ No newline at end of file
+            # 数据导入
+            for i in range(1, data_total):
+                row = data[i]
+                order_no = row[order_no_index]
+                express_no = row[express_no_index]
+                express_company = row[express_company_index]
+
+                if order_no and express_no and express_company:
+                    update_sql = "order_status=1,express_no=%s,express_company=%s,deliver_date=%s,modify_date=%s"
+                    params = [express_no, express_company, self.get_now_datetime(), self.get_now_datetime(), order_no, act_id]
+                    prize_order_model.update_table(update_sql, "order_no=%s and act_id=%s", params=params)
+                    prize_roster_model.update_table("order_status=1", "order_no=%s and act_id=%s", [order_no, act_id])
+            os.remove(path)
+
+        return self.reponse_json_success()
