@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-12 20:04:54
-:LastEditTime: 2021-08-04 17:29:36
-:LastEditors: HuangJingCan
+@LastEditTime: 2021-09-01 15:50:38
+@LastEditors: HuangJianYi
 :description: 用户相关
 """
 from seven_cloudapp.handlers.seven_base import *
@@ -27,6 +27,7 @@ from seven_cloudapp.handlers.server.user_s import UserDetailHandler
 from seven_cloudapp.handlers.server.user_s import PropLogHandler
 
 from seven_cloudapp_ppmt.models.db_models.machine.machine_info_model import *
+from seven_cloudapp_ppmt.models.db_models.prop.prop_give_model import *
 
 
 class UserListHandler(SevenBaseHandler):
@@ -459,4 +460,68 @@ class PropHandler(SevenBaseHandler):
         prop_log.create_date = self.get_now_datetime()
         prop_log_model.add_entity(prop_log)
 
-        return self.reponse_json_success()
\ No newline at end of file
+        return self.reponse_json_success()
+
+
+class PropGiveListHandler(SevenBaseHandler):
+    """
+    :description: 道具赠送记录列表
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description: 道具赠送记录列表
+        :param page_index：页索引
+        :param page_size：页大小
+        :param act_id：活动id
+        :param user_open_id：赠送人open_id
+        :param nick_name：赠送人淘宝名
+        :param draw_open_id：领取人open_id
+        :param draw_nick_name：领取人淘宝名
+        :param start_date：开始时间
+        :param end_date：结束时间
+        :param give_status：赠送状态(0未领取1已领取2已失效)
+        :return list
+        :last_editors: HuangJianYi
+        """
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 20))
+        act_id = int(self.get_param("act_id", 0))
+        user_nick = self.get_param("nick_name")
+        user_open_id = self.get_param("user_open_id")
+        draw_user_nick = self.get_param("draw_nick_name")
+        draw_open_id = self.get_param("draw_open_id")
+        start_date = self.get_param("start_date")
+        end_date = self.get_param("end_date")
+        give_status = int(self.get_param("give_status", -1))
+
+        condition = "act_id=%s"
+        params = [act_id]
+
+        if give_status >= 0:
+            condition += " AND give_status=%s"
+            params.append(give_status)
+        if user_open_id:
+            condition += " AND open_id=%s"
+            params.append(user_open_id)
+        if user_nick:
+            condition += " AND user_nick=%s"
+            params.append(user_nick)
+        if draw_open_id:
+            condition += " AND draw_open_id=%s"
+            params.append(draw_open_id)
+        if draw_user_nick:
+            condition += " AND draw_user_nick=%s"
+            params.append(draw_user_nick)
+        if start_date:
+            condition += " AND create_date>=%s"
+            params.append(start_date)
+        if end_date:
+            condition += " AND create_date<=%s"
+            params.append(end_date)
+
+        page_list, total = PropGiveModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
+
+        page_info = PageInfo(page_index, page_size, total, page_list)
+
+        return self.reponse_json_success(page_info)
\ No newline at end of file
